from Products.CMFCore.utils import getToolByName
from Persistence import PersistentMapping

import logging

PROFILE_ID='profile-cs.editablefooter:default'

def upgrade_to_1001(context, logger=None):
    """Upgrade to cs.editablefooter 2.0"""
    if logger is None:
        # Called as upgrade step: define our own logger.
        logger = logging.getLogger('cs.editablefooter')

    setup = getToolByName(context, 'portal_setup')
    # Remove previous controlpanel registration
    controlpanel = getToolByName(context, 'portal_controlpanel')
    controlpanel.unregisterConfiglet('EditableFooter')
    # import permission settings
    setup.runImportStepFromProfile(PROFILE_ID, 'rolemap')
    # import new controlpanel
    setup.runImportStepFromProfile(PROFILE_ID, 'controlpanel')
    logger.info("All set")


from zope import schema
from zope.interface import Interface

from cs.editablefooter import EditableFooterMessageFactory as _

class IProductLayer(Interface):
    """ Custom interface for our layer """

class IEditableFooter(Interface):
    """ The infterface for the editable footer """

    footer_text = schema.Text(title=_(u'Footer text'),
                              description=_(u'Insert here the HTML that will appear in the footer'),
                              required=False,
                              )



from setuptools import setup, find_packages
import os

version = '2.1.1'

setup(name='cs.editablefooter',
      version=version,
      description="A simple package providing a editable footer for Plone",
      long_description=open("README.rst").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Programming Language :: Python",
        ],
      keywords='plone viewlet footer',
      author='Mikel Larreategi',
      author_email='mlarreategi@codesyntax.com',
      url='http://github.com/codesyntax/cs.editablefooter',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['cs'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-

      [z3c.autoinclude.plugin]
      target = plone
      """,
      )



__version__ = '$Id$'

from zope.component import adapts
from zope.interface import implements
from zope.formlib import form

from plone.app.controlpanel.form import ControlPanelForm
from plone.app.layout.viewlets.common import ViewletBase

try:
    from plone.app.form.widgets.wysiwygwidget import WYSIWYGWidget
    KUPU_WIDGET = True
except ImportError:
    KUPU_WIDGET = False


from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from Products.CMFDefault.formlib.schema import SchemaAdapterBase
from Products.CMFPlone.utils import safe_unicode
from Products.CMFPlone.interfaces import IPloneSiteRoot
from Products.CMFCore.utils import getToolByName

from cs.editablefooter import EditableFooterMessageFactory as _
from cs.editablefooter.interfaces import IEditableFooter
class EditableFooterControlPanelAdapter(SchemaAdapterBase):
    adapts(IPloneSiteRoot)
    implements(IEditableFooter)

    def __init__(self, context):
        super(EditableFooterControlPanelAdapter, self).__init__(context)
        self.portal = context
        pprop = getToolByName(self.portal, 'portal_properties')
        self.context = pprop.site_properties
        self.encoding = pprop.site_properties.default_charset
        self.fprops = pprop.footer_properties

    def get_footer_text(self):
        language = self.portal.REQUEST.get('LANGUAGE', '')
        ida='footer_text_' + language
        text = getattr(self.fprops, ida, u'')
        return safe_unicode(text)

    def set_footer_text(self, value):
        language = self.portal.REQUEST.get('LANGUAGE', '')
        ida='footer_text_' + language
        if value is not None:
            value=value.encode(self.encoding)
        else:
            value=''

        if self.fprops.hasProperty(ida):
            setattr(self.fprops, ida, value)
        else:
            self.fprops.manage_addProperty(ida,value,'text')


    footer_text = property(get_footer_text, set_footer_text)



class EditableFooterControlPanel(ControlPanelForm):
    form_fields = form.FormFields(IEditableFooter)

    if KUPU_WIDGET:
        form_fields['footer_text'].custom_widget = WYSIWYGWidget

    form_name = _(u'Editable footer')
    label = _(u'Editable footer content')
    description = _(u'Enter the content of the footer')


class EditableFooterViewlet(ViewletBase):

    def update(self):
        language = self.request.get('LANGUAGE', '')
        ida='footer_text_' + language
        pprops = getToolByName(self.context, 'portal_properties')
        fprops = pprops.footer_properties
        text = getattr(fprops, ida, u'')

        transforms = getToolByName(self.context, 'portal_transforms', None)
        data = transforms.convertTo('text/x-html-safe',
                                    text,
                                    mimetype='text/html',
                                    context=self.context)
        if data is None:
            self.footer_text = safe_unicode(text)
        else:
            output = data.getData()
            self.footer_text = safe_unicode(output)


    render = ViewPageTemplateFile('footer.pt')
